@@ -18,15 +18,15 @@ T = TypeVar("T", bound=Union[BaseModel, DataclassProtocol])
 
 class SyncPersistenceProtocol(Protocol[T]):
     def save(self, data: T) -> T:
-        """Persist a single instance synchronously"""
+        """Persist a single instance synchronously."""
 
     def save_many(self, data: List[T]) -> List[T]:
-        """Persist multiple instances synchronously"""
+        """Persist multiple instances synchronously."""
 
 
 class AsyncPersistenceProtocol(Protocol[T]):
     async def save(self, data: T) -> T:
-        """Persist a single instance asynchronously"""
+        """Persist a single instance asynchronously."""
 
     async def save_many(self, data: List[T]) -> List[T]:
-        """Persist multiple instances asynchronously"""
+        """Persist multiple instances asynchronously."""
